aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--packages/pipeline/migrations/1548809952793-AllowDuplicateTxHashesInDexTrades.ts4
1 files changed, 3 insertions, 1 deletions
diff --git a/packages/pipeline/migrations/1548809952793-AllowDuplicateTxHashesInDexTrades.ts b/packages/pipeline/migrations/1548809952793-AllowDuplicateTxHashesInDexTrades.ts
index 1b396918e..21b08f0ef 100644
--- a/packages/pipeline/migrations/1548809952793-AllowDuplicateTxHashesInDexTrades.ts
+++ b/packages/pipeline/migrations/1548809952793-AllowDuplicateTxHashesInDexTrades.ts
@@ -6,7 +6,9 @@ export class AllowDuplicateTxHashesInDexTrades1548809952793 implements Migration
public async up(queryRunner: QueryRunner): Promise<any> {
const dexTradesTable = await queryRunner.getTable(DEX_TRADES_TABLE_NAME);
if (dexTradesTable) {
- // Composite key goes from (source_url, tx_hash) to (trade_index, source_url, tx_hash)
+ // Need new primary key to be non-null. No default value makes sense, so drop table.
+ await queryRunner.query(`DELETE from ${DEX_TRADES_TABLE_NAME}`);
+ // Composite key goes from (source_url, tx_hash) to (source_url, tx_hash, trade_index)
await queryRunner.addColumn(
DEX_TRADES_TABLE_NAME,
new TableColumn({